Module orphan

Module orphan 

Orphan namespace of the module.

Modules

mat
Matrix and all related.
mat2x2
2D entities with 2 along both dimensions. Useful for 2D graphics.
mat2x2h
2D entities with 2+homogenous coordinate along both dimensions. Useful for 2D graphics.
mat3x3
3D entities with 3 along both dimensions. Useful for 3D graphics
mat3x3h
3D entities with 3+homogenous coordinate along both dimensions. Useful for 3D graphics.
mat4x4
General functions for 4x4 matrices

Structs

Mat
A matrix structure.

Traits

MatEl
Trait for indicating that a type can be used as a matrix element.
MatWithShape
A trait indicate that matrix in case of referencing it can be interpreted as such having specified shape ROWS x COLS.
MatWithShapeMut
A trait indicate that matrix in case of mutable referencing it can be interpreted as such having specified shape ROWS x COLS.
Rotation
Trait for representing and manipulating rotations.

Type Aliases

F32x2x2
Type aliases for 2x2 f32 column major matrix.
F32x3x3
Type aliases for 3x3 f32 column major matrix.
F32x4x4
Type aliases for 4x4 f32 column major matrix.
F64x2x2
Type aliases for 2x2 f64 column major matrix.
F64x3x3
Type aliases for 3x3 f64 column major matrix.
F64x4x4
Type aliases for 4x4 f64 column major matrix.
Mat2
Type aliases for 2x2 matrix.
Mat3
Type aliases for 3x3 matrix.
Mat4
Type aliases for 4x4 matrix.