pub trait RawSlice: Collection { // Required method fn raw_slice(&self) -> &[Self::Scalar]; }
Provides immutable access to the underlying data of a collection as a flat slice.
Returns a reference to the underlying data as a flat array.