Module own

Module own 

Own namespace of the module.

Modules

access
Defines traits and methods for accessing the components or elements of data structures. Defines traits and methods for accessing the components or elements of data structures.
attribute
Defines traits and methods for getting and setting specific attributes or properties. Defines traits and methods for getting and setting specific attributes or properties.

Traits

Collection
A trait for collections of scalars.
ConstLayout
Trait for setting values in a matrix.
Indexable
Trait for objects that have an indexable dimension.
IndexingMut
Trait for indexing and iterating over matrix elements with mutable access.
IndexingRef
Trait for indexing and iterating over matrix elements.
RawSlice
Provides immutable access to the underlying data of a collection as a flat slice.
RawSliceMut
Trait for accessing and modifying the underlying data of a collection as a mutable slice.
ScalarMut
Trait for setting values in a matrix.
ScalarRef
Trait for setting values in a matrix.
StrideTrait
Trait for objects that have a stride.
Zero
Defines an additive identity element for Self.