Vector

Struct Vector 

pub struct Vector<E, const LEN: usize>(pub [E; LEN])
where
    E: MatEl;
A vector structure.

Tuple Fields

0: [E; LEN]

Implementations

Source

impl<E, const N: usize> Vector<E, N>
where E: MatEl,

pub const fn splat(v: E) -> Self

Creates a vector from a single value : [ v ; N ]

pub fn to_array(&self) -> [E; N]

Return underlying array data

pub fn from_array(src: [E; N]) -> Self

Creates vector from given raw array

pub fn from_slice(src: &[E]) -> Self

Creates vector from given raw slice. Assumes slice’s length is equal to vector size

Panics

Panics if src lenght does not match vector size

Source

impl<E: MatEl + NdFloat, const LEN: usize> Vector<E, LEN>

pub fn normalize(self) -> Self

Normalizes the vector

pub fn mag(&self) -> E

Compute the length of the vector

pub fn mag2(&self) -> E

Computer the squared length of the vector

pub fn min(self, rhs: Self) -> Self

Compute a vector, whose elements are minimum of both vectors: r[ i ] = a[ i ].min( b [ i ] )

pub fn max(self, rhs: Self) -> Self

Compute a vector, whose elements are maximum of both vectors: r[ i ] = a[ i ].max( b [ i ] )

pub fn distance(&self, rhs: &Self) -> E

Computes length of the vector between two points in space

pub fn distance_squared(&self, rhs: &Self) -> E

Computes squared length of the vector between two points in space

pub fn dot(&self, rhs: &Self) -> E

Computes the dot product of two vectors

Source

impl<E> Vector<E, 2>
where E: MatEl + NdFloat,

pub const fn new(x: E, y: E) -> Self

Create a new vector

pub fn x(&self) -> E

The x component of vector

pub fn y(&self) -> E

The y component of vector

Source

impl Vector<f32, 2>

pub const X: Self

Unit x vector

pub const Y: Self

Unit y vector

pub const NEG_X: Self

Minus unit x vector

pub const NEG_Y: Self

Minus unit y vector

pub const MIN: Self

All elements are f32::MIN

pub const MAX: Self

All elements are f32::MAX

pub const ZERO: Self

All elemets are ZERO

Source

impl<E> Vector<E, 3>
where E: MatEl + NdFloat,

pub const fn new(x: E, y: E, z: E) -> Self

Create a new vector

pub fn x(&self) -> E

The x component of vector

pub fn y(&self) -> E

The y component of vector

pub fn z(&self) -> E

The z component of vector

pub fn cross(self, rhs: Self) -> Self

Calculates cross product with another vector

pub fn to_homogenous(self) -> Vector<E, 4>

Creates homogeneous vector from self

Source

impl Vector<f32, 3>

pub const X: Self

Unit x vector

pub const Y: Self

Unit y vector

pub const Z: Self

Unit z vector

pub const NEG_X: Self

Minus unit x vector

pub const NEG_Y: Self

Minus unit y vector

pub const NEG_Z: Self

Minus unit z vector

pub const MIN: Self

All elements are f32::MIN

pub const MAX: Self

All elements are f32::MAX

pub const ZERO: Self

All elemets are ZERO

Source

impl<E> Vector<E, 4>
where E: MatEl + NdFloat,

pub const fn new(x: E, y: E, z: E, w: E) -> Self

Create a new vector

pub fn x(&self) -> E

The x component of vector

pub fn y(&self) -> E

The y component of vector

pub fn z(&self) -> E

The z component of vector

pub fn w(&self) -> E

The w component of vector

pub fn truncate(&self) -> Vector<E, 3>

Truncates w component of a vector creating vector of 3 elements

Source

impl Vector<f32, 4>

pub const X: Self

Unit x vector

pub const Y: Self

Unit y vector

pub const Z: Self

Unit z vector

pub const W: Self

Unit w vector

pub const NEG_X: Self

Minus unit x vector

pub const NEG_Y: Self

Minus unit y vector

pub const NEG_Z: Self

Minus unit z vector

pub const NEG_W: Self

Minus unit w vector

pub const MIN: Self

All elements are f32::MIN

pub const MAX: Self

All elements are f32::MAX

pub const ZERO: Self

All elemets are ZERO

Methods from Deref<Target = [E; N]>

1.57.0 · Source

pub fn as_slice(&self) -> &[T]

Returns a slice containing the entire array. Equivalent to &s[..].

1.57.0 · Source

pub fn as_mut_slice(&mut self) -> &mut [T]

Returns a mutable slice containing the entire array. Equivalent to &mut s[..].

1.77.0 · Source

pub fn each_ref(&self) -> [&T; N]

Borrows each element and returns an array of references with the same size as self.

Example
let floats = [3.1, 2.7, -1.0];
let float_refs: [&f64; 3] = floats.each_ref();
assert_eq!(float_refs, [&3.1, &2.7, &-1.0]);

This method is particularly useful if combined with other methods, like map. This way, you can avoid moving the original array if its elements are not Copy.

let strings = ["Ferris".to_string(), "♥".to_string(), "Rust".to_string()];
let is_ascii = strings.each_ref().map(|s| s.is_ascii());
assert_eq!(is_ascii, [true, false, true]);

// We can still access the original array: it has not been moved.
assert_eq!(strings.len(), 3);
1.77.0 · Source

pub fn each_mut(&mut self) -> [&mut T; N]

Borrows each element mutably and returns an array of mutable references with the same size as self.

Example

let mut floats = [3.1, 2.7, -1.0];
let float_refs: [&mut f64; 3] = floats.each_mut();
*float_refs[0] = 0.0;
assert_eq!(float_refs, [&mut 0.0, &mut 2.7, &mut -1.0]);
assert_eq!(floats, [0.0, 2.7, -1.0]);
pub fn split_array_ref<const M: usize>(&self) -> (&[T; M], &[T])

🔬This is a nightly-only experimental API. (split_array)

Divides one array reference into two at an index.

The first will contain all indices from [0, M) (excluding the index M itself) and the second will contain all indices from [M, N) (excluding the index N itself).

Panics

Panics if M > N.

Examples
#![feature(split_array)]

let v = [1, 2, 3, 4, 5, 6];

{
   let (left, right) = v.split_array_ref::<0>();
   assert_eq!(left, &[]);
   assert_eq!(right, &[1, 2, 3, 4, 5, 6]);
}

{
    let (left, right) = v.split_array_ref::<2>();
    assert_eq!(left, &[1, 2]);
    assert_eq!(right, &[3, 4, 5, 6]);
}

{
    let (left, right) = v.split_array_ref::<6>();
    assert_eq!(left, &[1, 2, 3, 4, 5, 6]);
    assert_eq!(right, &[]);
}
pub fn split_array_mut<const M: usize>(&mut self) -> (&mut [T; M], &mut [T])

🔬This is a nightly-only experimental API. (split_array)

Divides one mutable array reference into two at an index.

The first will contain all indices from [0, M) (excluding the index M itself) and the second will contain all indices from [M, N) (excluding the index N itself).

Panics

Panics if M > N.

Examples
#![feature(split_array)]

let mut v = [1, 0, 3, 0, 5, 6];
let (left, right) = v.split_array_mut::<2>();
assert_eq!(left, &mut [1, 0][..]);
assert_eq!(right, &mut [3, 0, 5, 6]);
left[1] = 2;
right[1] = 4;
assert_eq!(v, [1, 2, 3, 4, 5, 6]);
pub fn rsplit_array_ref<const M: usize>(&self) -> (&[T], &[T; M])

🔬This is a nightly-only experimental API. (split_array)

Divides one array reference into two at an index from the end.

The first will contain all indices from [0, N - M) (excluding the index N - M itself) and the second will contain all indices from [N - M, N) (excluding the index N itself).

Panics

Panics if M > N.

Examples
#![feature(split_array)]

let v = [1, 2, 3, 4, 5, 6];

{
   let (left, right) = v.rsplit_array_ref::<0>();
   assert_eq!(left, &[1, 2, 3, 4, 5, 6]);
   assert_eq!(right, &[]);
}

{
    let (left, right) = v.rsplit_array_ref::<2>();
    assert_eq!(left, &[1, 2, 3, 4]);
    assert_eq!(right, &[5, 6]);
}

{
    let (left, right) = v.rsplit_array_ref::<6>();
    assert_eq!(left, &[]);
    assert_eq!(right, &[1, 2, 3, 4, 5, 6]);
}
pub fn rsplit_array_mut<const M: usize>(&mut self) -> (&mut [T], &mut [T; M])

🔬This is a nightly-only experimental API. (split_array)

Divides one mutable array reference into two at an index from the end.

The first will contain all indices from [0, N - M) (excluding the index N - M itself) and the second will contain all indices from [N - M, N) (excluding the index N itself).

Panics

Panics if M > N.

Examples
#![feature(split_array)]

let mut v = [1, 0, 3, 0, 5, 6];
let (left, right) = v.rsplit_array_mut::<4>();
assert_eq!(left, &mut [1, 0]);
assert_eq!(right, &mut [3, 0, 5, 6][..]);
left[1] = 2;
right[1] = 4;
assert_eq!(v, [1, 2, 3, 4, 5, 6]);