VectorSpaceMut

Trait VectorSpaceMut 

pub trait VectorSpaceMut<const SIZE: usize>
where Self: VectorSpace<SIZE> + VectorIterMut<<Self as Collection>::Scalar, SIZE>,
{ }
A marker trait that extends VectorSpace with mutable iteration capabilities.

This provides a convenient bound for generic functions that require mutable access to the elements of a vector-like type. Any type that implements VectorSpace and VectorIterMut will automatically implement VectorSpaceMut.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementors

Source

impl<T, const SIZE: usize> VectorSpaceMut<SIZE> for T
where Self: VectorSpace<SIZE> + VectorIterMut<<Self as Collection>::Scalar, SIZE>,