Exposed namespace of the module.
Structs
- Mat
- A matrix structure.
Traits
- MatEl
- Trait for indicating that a type can be used as a matrix element.
- MatWith
Shape - A trait indicate that matrix in case of referencing it can be interpreted as such having specified shape
ROWS x COLS. - MatWith
Shape Mut - A trait indicate that matrix in case of mutable referencing it can be interpreted as such having specified shape
ROWS x COLS.
Type Aliases
- F32x2x2
- Type aliases for 2x2
f32column major matrix. - F32x3x3
- Type aliases for 3x3
f32column major matrix. - F32x4x4
- Type aliases for 4x4
f32column major matrix. - F64x2x2
- Type aliases for 2x2
f64column major matrix. - F64x3x3
- Type aliases for 3x3
f64column major matrix. - F64x4x4
- Type aliases for 4x4
f64column major matrix. - Mat2
- Type aliases for 2x2 matrix.
- Mat3
- Type aliases for 3x3 matrix.
- Mat4
- Type aliases for 4x4 matrix.