pub trait IntoVector<E, const N: usize>where
E: MatEl,{
// Required method
fn into_vector(self) -> Vector<E, N>;
// Provided method
fn as_vector(&self) -> Vector<E, N>
where Self: Clone { ... }
}Expand description
A trait for types that can be converted into a Vector.
This provides a common interface for various data structures
to be transformed into a Vector type.
Required Methods
Sourcefn into_vector(self) -> Vector<E, N>
fn into_vector(self) -> Vector<E, N>
Consumes the object and converts it into a Vector<E, N>.